<?php 
//https://github.com/AfterShip/aftership-sdk-php

class WCAFW_AfterShip
{
	var $api_key;
	var $courier_slugs = array();
	var $trackings = null;
	var $courier = null;
	var $last_check_point = null;
	var $already_init = false;
	public function __construct($key)
	{
		include_once WCAFW_PLUGIN_ABS_PATH.'/classes/vendor/autoload.php';
		$this->api_key = $key;
		
	}
	private function init_connectors()
	{
		if(!$this->already_init)
		{
			$this->already_init = true;
			$this->trackings = new AfterShip\Trackings($this->api_key);
			$this->courier = new AfterShip\Couriers($this->api_key);
			$this->last_check_point = new AfterShip\LastCheckPoint($this->api_key);
		}
	}
	public function is_api_key_valid()
	{
		try 
		{
			$this->init_connectors();
			$is_valid = true;
			try
			{
				$this->courier->all();
			}catch(AfterShip\AfterShipException $e)
			{
				$is_valid = false;
			}
		}catch(Exception $e) {$is_valid = false;}
		return $is_valid;
	}
	public function get_tracking()
	{
		
	}
	public function detect_courier_slug_by_tracking_id($tracking_code, $slug = null)
	{
		$this->init_connectors();
		$courier = $this->courier;
		$slug_to_use_for_detection = $slug;
		if(empty($this->courier_slugs) && !isset($slug))
		{
			$complete_courier_list = $courier->all();
			foreach((array)$complete_courier_list["data"]["couriers"] as $courier_data)
				$this->courier_slugs[] = $courier_data["slug"];
				
			$slug_to_use_for_detection =  $this->courier_slugs;
		}
		$slug_to_use_for_detection = isset($slug_to_use_for_detection) && is_array($slug_to_use_for_detection) ?  implode(",", $slug_to_use_for_detection) : $slug_to_use_for_detection;
		$response = $courier->detect($tracking_code, array('slug' => $slug_to_use_for_detection));
		return $response;
	}
	//updates (or cretes if not existing) the tracking info
	public function update_tracking($data)
	{
		$courier_slug = $data['company_code'];
		$tracking_code = $data['tracking_code'];
		$this->init_connectors();
		$trackings = $this->trackings;
		$response;
		$tracking_info = [
			'slug'    => $courier_slug,
			
		];
		foreach($data['optional_parameters'] as $param_key => $param_value)
			$tracking_info[$param_key] = $param_value;
		try
		{
			$response = $trackings->create($tracking_code, $tracking_info);
			
		}catch(Exception $e) //AfterShipException
		{
			
			$response = $trackings->update($courier_slug, $tracking_code, $data['optional_parameters']);
			return array('result'=> false, 'response' => $response); 
		}
		return array('result'=> true, 'response' => $response);
	}
	public function get_last_checkpoint($courier_slug, $tracking_code, $order_id )
	{
		global $wcafw_order_model;
		$this->init_connectors();
		$last_check_point = $this->last_check_point;
		
		//Additional parameters
		
		$params = array('tracking_postal_code' => $wcafw_order_model->get_shipping_post_code($order_id));
		
		$response = $last_check_point->get($courier_slug, $tracking_code, $params);
		
		return $response;
	}
	public function get_tracking_info($data, $lang, $order_id)
	{
		$courier_slug = $data['company_code'];
		$tracking_code = $data['tracking_code'];
		$this->init_connectors();
		$trackings = $this->trackings;
		
		try
		{
			$last_check_point = $this->last_check_point;
			$response = $this->get_last_checkpoint($courier_slug, $tracking_code, $order_id);
			
		}catch(Exception $e){return 'no_data';}
		$id = $response["data"]["id"];
		$response = $trackings->getById($id, array('lang' => $lang));
		
		return $response;
	}
	
	public function delete_by_slug($data)
	{
		$courier_slug = $data['company_code'];
		$tracking_code = $data['tracking_code'];
		$this->init_connectors();
		$trackings = $this->trackings;
		return $trackings->delete($courier_slug, $tracking_code);
	}
	public function delete_shipping_tracking_by_id($id)
	{
		try 
		{
			$this->init_connectors();
			$trackings = $this->trackings;
			$trackings->deleteById($id);
		}catch(Exception $e){$response = false; }
	}
	public function delete_all_tracking_id()
	{
		$this->init_connectors();
		$trackings = $this->trackings;
		/* 		 
		$options = [
			'page'  => 1,
			'limit' => 1000
		];  */
		$result = $trackings->all(/* $options */);
		if(isset($result["data"]) && isset($result["data"]["trackings"]))
			foreach($result["data"]["trackings"] as $tracking)
				$trackings->deleteById($tracking["id"]); 
	}
	public function render_tracking_info_box($data, $lang, $order_id)
	{
		global $wcafw_time_model, $wcafw_option_model, $wcafw_product_model;
		
		$options = $wcafw_option_model->get_options();
		$display_collapse_button =  wcafw_get_value_if_set($options, array('frontend_order_details_page', 'timeline_show_collapsed'), 'no') == 'yes';
		$wc_order = wc_get_order($order_id);
		foreach((array)$data as $unique_id => $tracking_data)
		{
			$tracking_info = $this->get_tracking_info($tracking_data, $lang, $order_id);
			
			//wcafw_var_dump($tracking_info);
			//Errors
			if($tracking_info == false)
			{
				echo "<h3><img class='wcafw_courier_logo' width='32' src='https://assets.aftership.com/couriers/svg/".$tracking_data['company_code'].".svg'></img>".$company_name.": ".$tracking_number." - ". esc_html__( 'Tracking service unavailable at the moment. Please try again later.', 'woocommerce-aftership' )."</h3>";
				continue;
			}
			else if($tracking_info  == 'no_currier_detected')
			{
				echo "<h3><img class='wcafw_courier_logo' width='32' src='https://assets.aftership.com/couriers/svg/".$tracking_data['company_code'].".svg'></img>".$company_name.": ".$tracking_number." - ". esc_html__( 'No currier detected for the selected tracking code.', 'woocommerce-aftership' )."</h3>";
				continue;
			}
			else if($tracking_info  == 'no_data')
			{
				continue;
			}
			
			$expected_delivery = $tracking_info['data']['tracking']['expected_delivery'] != null ? $wcafw_time_model->format_data_according_wordpress_settings($tracking_info['data']['tracking']['expected_delivery'], false) : "";
			$status_message = $tracking_info['data']['tracking']['subtag_message'];
			$tracking_number = $tracking_info["data"]["tracking"]['tracking_number'];
			$company_name = $wcafw_option_model->get_company_by_name($tracking_info["data"]["tracking"]['slug']);
			$company_slug = $tracking_info["data"]["tracking"]['slug'];
			$status =  strtolower( $tracking_info["data"]["tracking"]["tag"]);
			$tracking_checkpoints =  $tracking_info["data"]["tracking"]["checkpoints"];
			$collapse_id = rand(1312, 999999);
			$collapse_elem_to_show = count($tracking_checkpoints) - 1;
			$collapse_counter = 0;
			
			if(empty($tracking_checkpoints))
			{
				echo "<h3><img class='wcafw_courier_logo' width='32' src='https://assets.aftership.com/couriers/svg/".$tracking_data['company_code'].".svg'></img>".$company_name.": ".$tracking_number." - ". esc_html__( 'No tracking info avaliable at the moment. Please try again later.', 'woocommerce-aftership' )."</h3>";
				continue;
			}
			
			if(wcafw_get_value_if_set($options, array('frontend_order_details_page', 'timeline_events_order'), 'oldest_to_recent') == 'recent_to_oldest')
			{
				$tracking_checkpoints = array_reverse($tracking_checkpoints);
				$collapse_elem_to_show = 0;
			}
			
			$counter = 1;
			if($status == 'pending'):
				echo "<h3>". esc_html__( 'Please try again later, we are awaiting tracking info from the carrier.', 'woocommerce-aftership' )."</h3>";
			else:
				?>
				<h2 class="wcafw_shipping_company_name"><img class='wcafw_courier_logo' width='32' src='https://assets.aftership.com/couriers/svg/<?php echo $tracking_data['company_code']; ?>.svg'></img><?php echo $company_name.": ".$tracking_number;?> <?php if($display_collapse_button):?><a href="#" data-id="<?php echo $collapse_id;?>" class="wcafw_collapse_button" data-status="show"><?php  esc_html_e( '(click for details)', 'woocommerce-aftership' );?></a><?php endif;?></h2>
				<?php 
					if($associated_product = wcafw_get_value_if_set($tracking_data, 'associated_product', array()) ) : ?>
					<div class="wcfa_associated_product_container">
						<span class="wcfa_associated_product_prefix"><?php esc_html_e( 'Ships: ', 'woocommerce-aftership' ); ?></span>
						<?php 
							$order_items_counter = 0;
							foreach($wc_order->get_items() as $order_item)
							{
								if(in_array($order_item->get_id(), $associated_product))
								{
									$attributes = $wcafw_product_model->get_order_variation_attribute_value_and_name($order_item->get_product());
									
									if($order_items_counter++ >0) echo ", ";
									echo "<span class='wcfa_associated_product_text'>".$order_item->get_name()." ".$attributes."</span>";
								}
								
							}
						?>
					</div>
					<?php endif; ?>
					
				<div class="wcafw_staus_container <?php echo "wcafw_staus_container_".$status; ?>">
					<span class="<?php echo $expected_delivery == "" ? 'wcafw_status_full_text' : 'wcafw_status_left_text'?>"><?php echo $status_message; ?></span>
					<?php if($expected_delivery != ""): ?>
						<span class="wcafw_status_right_text"><?php echo sprintf( esc_html__( 'scheduled: %s', 'woocommerce-aftership' ), $expected_delivery); ; ?></span>
					<?php endif;?>
				</div>
				<ul class="uk-list">
					<?php 
					foreach($tracking_checkpoints as $tracking_checkpoint):
							$current_status = strtolower($tracking_checkpoint["tag"]);
							
							$collapse_hide_current_elem = $display_collapse_button && $collapse_counter != $collapse_elem_to_show;
							$collapse_counter++;
							
					?>
						
						
						<li class="uk-flex info-item">
							<div class="checkpoint" style="background: rgba(0, 0, 0, 0) url('<?php echo WCAFW_PLUGIN_PATH; ?>/img/aftership/<?php echo $current_status;?>.svg') repeat scroll 0% 0% / contain;"></div> 
							<div class="info-checkpoint">
								<div class="info-date">
									<?php echo $wcafw_time_model->format_data_according_wordpress_settings ( $tracking_checkpoint["checkpoint_time"] ); //2018-02-24T18:11:10 ?> .<?php echo $tracking_checkpoint["location"]; ?>
								</div> 
								<div class="info-desc">
									<?php echo $tracking_checkpoint["message"]; ?>
								</div>
							</div>
						</li>						
					<?php endforeach; ?>
				</ul>
				<?php 
			endif;
		}
		/* return ob_get_clean(); */
	}
}
?>