<?php 
class WCAFW_Email
{
	public function __construct()
	{
		add_action('init', array(&$this, 'setup'));
	}
	public function setup()
	{
		global $wcafw_option_model, $wcafw_order_model;
		
		$options = $wcafw_option_model->get_email_options();
		
		add_action($options['position'], array(&$this, 'render_tracking_data'), 10, 4);	
	}
	
	public function render_tracking_data($order, $sent_to_admin, $plain_text, $email = null)
	{
		global $wcafw_option_model, $wcafw_order_model, $wcafw_shortcode_model;
		
		if(!isset($order) || !is_object($order))
			return;
		$reflect = new \ReflectionClass($order);
		if($sent_to_admin || ($reflect->getShortName() !== "Order" && $reflect->getShortName() !== "Admin_Order"))
			return;
		
		$email_settings = $wcafw_option_model->get_email_options();
		
		//1 - Check order status (remove wc- prefix)
		if(wcafw_get_value_if_set($email_settings,array('order_statuses', $order->get_status()), false) == false)
				return;
			
		$message = wcafw_get_value_if_set($email_settings , array('message', $wcafw_order_model->get_lang($order)), "");
		
		//2 - Shortcode processing (for each tracking data)
		$final_messages = $wcafw_shortcode_model->replace_shortcodes($message, $order);
		
		include WCAFW_PLUGIN_ABS_PATH.'/templates/wc_email.php';
		
	}
	public function send_active_notification_email_with_tracking_codes($wc_order, $tracking_data)
	{
		global $wcafw_option_model, $wcafw_order_model, $wcafw_shortcode_model;
		
		$email_options = $wcafw_option_model->get_email_options();
		$order_lang = $wcafw_order_model->get_lang($wc_order);
		$recipients = $wc_order->get_billing_email();
		$subject = wcafw_get_value_if_set($email_options , array('active_notification', 'subject', $order_lang), "");
		$template = wcafw_get_value_if_set($email_options , array('active_notification', 'template', $order_lang), "");
		$tracking_message = wcafw_get_value_if_set($email_options , array('active_notification', 'tracking_message', $order_lang), "");
		$message = "";
		
		// 1 - remove from subject and tracking info
		$subject = str_replace("[tracking_message]", "", $subject);
		$tracking_message = str_replace("[tracking_message]", "", $tracking_message);
		
		// 2 - replace the [tracking_message] from template with "", or [tracking_message_1], ... , [tracking_messag_n] according tracking info number 
		$template = $wcafw_shortcode_model->remove_tracking_message_shortcode($template, $tracking_data);
		
		// 3 - replace shortcodes from tracking message and insert in into the tempalte
		$template = $wcafw_shortcode_model->insert_tracking_info($wc_order, $tracking_data, $template, $tracking_message);
	
		//4 - replace shortcodes from subject and template
		$template = $wcafw_shortcode_model->shortcode_to_text($template,  $wc_order);
		$subject = $wcafw_shortcode_model->shortcode_to_text($subject,  $wc_order);
		
		$mail = WC()->mailer();
		ob_start();
		$mail->email_header(get_bloginfo('name'), $mail);
		echo stripcslashes($template);
		$mail->email_footer($mail);
		$message =  ob_get_contents();
		ob_end_clean(); 
		
		
		do_action('wcafw_before_active_notification_email', $tracking_data, $wc_order);
		
		add_filter('wp_mail_from_name',array(&$this, 'wp_mail_from_name'), 99, 1);
		add_filter('wp_mail_from', array(&$this, 'wp_mail_from'));
		$attachments =  array();
		if(!$mail->send( $recipients, $subject, $message, "Content-Type: text/html\r\n", $attachments)) //$mail->send || wp_mail
			wp_mail( $recipients, $subject, $message, "Content-Type: text/html\r\n", $attachments);
		remove_filter('wp_mail_from_name',array(&$this, 'wp_mail_from_name'));
		remove_filter('wp_mail_from',array(&$this, 'wp_mail_from'));
		
		do_action('wcafw_after_active_notification_email', $tracking_data, $wc_order);
	}
	public function wp_mail_from_name($name) 
	{
		return get_bloginfo('name');
	}
	public function wp_mail_from($content_type) 
	{
		$server_headers = function_exists('apache_request_headers') ? apache_request_headers() : wcafw_apache_request_headers();
		$domain = isset($server_headers['Host']) ? $server_headers['Host'] : null ;
		if(!isset($domain) && isset($_SERVER['HTTP_HOST']))
			$domain = str_replace("www.", "", $_SERVER['HTTP_HOST'] );
		
		return isset($domain) ? 'noprely@'.$domain : $content_type;
	}
}
?>